#INCLUDE "PROTHEUS.CH"
#INCLUDE "TRMR040.CH"

/*

Ŀ
Funo     TRMR040   Autor  Eduardo Ju               Data  09.06.06 
Ĵ
Descrio  Relatorio de Materiais por Curso.	                        
Ĵ
Sintaxe    TRMR040(void)                                                
Ĵ
 Uso       Generico                                                     
Ĵ
         ATUALIZACOES SOFRIDAS DESDE A CONSTRUAO INICIAL.               
Ĵ
Programador  Data      BOPS   Motivo da Alteracao                     
Ĵ
Tania       22/09/2006100338Acertos para o Relatorio personalizavel,  
                            do Release 4. Inclusao do Ajusta SX1.     
Pedro Eloy  17/10/2007133995Foi ajustado a busca da tabela RAH, pois  
                            ela  compartilhada ( no padrao ).        
ٱ

Ŀ
Programador   Data      FNC              Motivo da Alteracao                      
ĳ
Rogerio R.   29/07/200900000018271/2009Compatibilizacao dos fontes para aumento do
                                       campo filial e gesto corporativa.          
Luciana S.   10/08/201100000016958/2011Ajuste na exibicao dos titulos do relatorio
ٱ

*/
Function TRMR040()

Local oReport
Local aArea := GetArea()

If FindFunction("TRepInUse") .And. TRepInUse()	//Verifica se relatorio personalizal esta disponivel
	//Ŀ
	// Verifica as perguntas selecionadas                           
	//
	pergunte("TRR40A",.F.)
	oReport := ReportDef()
	oReport:PrintDialog()	
Else
	TRMR040R3()	
EndIf  

RestArea( aArea )

Return

/*

Ŀ
Funo    ReportDef()  Autor  Eduardo Ju           Data  09.06.06 
Ĵ
Descrio Definicao do Componente de Impressao do Relatorio           
Ĵ
Parametros                                                            
Ĵ
 Uso                                                                  
ٱ

*/
Static Function ReportDef()

Local oReport
Local oSection1
Local oSection2         
Local cAliasQry := GetNextAlias()

//Ŀ
//Criacao do componente de impressao                                      
//TReport():New                                                           
//ExpC1 : Nome do relatorio                                               
//ExpC2 : Titulo                                                          
//ExpC3 : Pergunte                                                        
//ExpB4 : Bloco de codigo que sera executado na confirmacao da impressao  
//ExpC5 : Descricao                                                       
//
oReport:=TReport():New("TRMR040",STR0001,"TRR40A",{|oReport| PrintReport(oReport,cAliasQry)},STR0011)	//"Este programa emite o Relatorio de Materiais por Curso"
oReport:SetTotalInLine(.F.) //Totaliza em linha

//Ŀ
//Criacao da celulas da secao do relatorio                                
//TRCell():New                                                            
//ExpO1 : Objeto TSection que a secao pertence                            
//ExpC2 : Nome da celula do relatrio. O SX3 ser consultado              
//ExpC3 : Nome da tabela de referencia da celula                          
//ExpC4 : Titulo da celula                                                
//        Default : X3Titulo()                                            
//ExpC5 : Picture                                                         
//        Default : X3_PICTURE                                            
//ExpC6 : Tamanho                                                         
//        Default : X3_TAMANHO                                            
//ExpL7 : Informe se o tamanho esta em pixel                              
//        Default : False                                                 
//ExpB8 : Bloco de cdigo para impressao.                                 
//        Default : ExpC2                                                 
//
//Ŀ
// Criacao da Primeira Secao:
// 
oSection1 := TRSection():New(oReport,STR0004,{"RAH"},/*aOrdem*/,/*Campos do SX3*/,/*Campos do SIX*/)	//"Solicitao de Treinamento"
oSection1:SetTotalInLine(.F.)     
TRCell():New(oSection1,"RAH_CURSO","RAH",STR0004)	//Codigo do Curso   
TRCell():New(oSection1,"RA1_DESC","RA1","")		//Descricao do Curso  

TRPosition():New(oSection1,"RA1",1,{|| xFilial("RA1") + RAH->RAH_CURSO}) 

//Ŀ
// Criacao da Segunda Secao: 
//
oSection2 := TRSection():New(oSection1,STR0010,{"RAH","RAG"},/*aOrdem*/,/*Campos do SX3*/,/*Campos do SIX*/)	//"Solicitao de Treinamento"	
oSection2:SetTotalInLine(.F.) 
TRCell():New(oSection2,"RAH_MATER","RAH",,,15,.T.)			//Codigo do Material
TRCell():New(oSection2,"RAG_DESC","RAG","")		//Descricao do Material
TRCell():New(oSection2,"RAH_REFER","RAH",,,15,.T.)			//Codigo da Referencia
TRCell():New(oSection2,"X5_DESCRI","SX5","",,30)	//Descricao da Referencia
TRCell():New(oSection2,"RAG_OBS","RAG")				//Observacoes

TRPosition():New(oSection2,"RAG",1,{|| xFilial("RAG") + RAH->RAH_MATER}) 
TRPosition():New(oSection2,"SX5",1,{|| xFilial("SX5") + "RI" + RAH->RAH_REFER}) 

TRFunction():New(oSection2:Cell("RAH_MATER"),/*cId*/,"COUNT",/*oBreak*/,/*cTitle*/,/*cPicture*/,/*uFormula*/,/*lEndSection*/,.F./*lEndReport*/,/*lEndPage*/)

Return oReport

/*

Ŀ
Funo    ReportDef()  Autor  Eduardo Ju           Data  13.06.06 
Ĵ
Descrio Impressao do Relatorio (Custo do Treinamento)               
Ĵ
Parametros                                                            
Ĵ
 Uso                                                                  
ٱ

*/
Static Function PrintReport(oReport,cAliasQry)

Local oSection1 := oReport:Section(1)
Local oSection2 := oReport:Section(1):Section(1)  
Local cFiltro := ""

#IFDEF TOP
	Local lQuery    := .F. 
#ENDIF

//Ŀ
// Variaveis utilizadas para parametros                         
// MV_PAR01        //  Filial  De                               
// MV_PAR02        //  Filial  Ate                              
// MV_PAR03        //  Curso De                                 
// MV_PAR04        //  Curso Ate                                
// MV_PAR05        //  Material De                              
// MV_PAR06        //  Material Ate                             
// MV_PAR07        //  Impr.Curso p/Folha                       
//

cFil := xFilial(NIL, MV_PAR01)

#IFNDEF TOP
	If !Empty(xFilial("RAH"))
		cFiltro += "RAH_FILIAL >= '" + cFil + "' .AND. "
		cFiltro += "RAH_FILIAL <= '" + MV_PAR02 + "' .AND. "
	EndIf
	
	cFiltro += "RAH_CURSO >= '" + MV_PAR03 + "' .AND. "
	cFiltro += "RAH_CURSO <= '" + MV_PAR04 + "' .AND. "
	cFiltro += "RAH_MATER >= '" + MV_PAR05 + "' .AND. "
	cFiltro += "RAH_MATER <= '" + MV_PAR06 + "'
	
	oSection1:SetFilter(cFiltro)
	oSection2:SetParentFilter({|cParam| RAH->RAH_CURSO == cParam},{|| RAH->RAH_CURSO})
	
	//Ŀ
	// Imprime Curso por Pagina  
	//
	If MV_PAR07 == 1   
		oBreak := TRBreak():New(oSection1,oSection1:Cell("RAH_CURSO"),"",.F.) 
		oBreak:SetPageBreak(.T.)	
	EndIf                          
	
	//Ŀ
	// Impressao do Relatorio    
	//
	oReport:SetMeter(RAH->(LastRec()))
	oSection1:Print()

#ELSE	

	//-- Filtragem do relatrio
	//-- Query do relatrio da secao 1
	lQuery := .T.          
	cOrder := "%RAH_FILIAL,RAH_CURSO%"        
	
	oReport:Section(1):BeginQuery()	

	BeginSql Alias cAliasQry
		
		SELECT	RAH_CURSO,RA1_DESC,RAH_MATER,RAG_DESC,RAH_REFER,X5_DESCRI,RAG_OBS								
				
		FROM 	%table:RAH% RAH  
		
		LEFT JOIN %table:RA1% RA1
			ON RA1_FILIAL = %xFilial:RA1%
			AND RA1_CURSO = RAH_CURSO
			AND RA1.%NotDel%
		LEFT JOIN %table:RAG% RAG
			ON RAG_FILIAL = %xFilial:RAG%
			AND RAG_MATER = RAH_MATER
			AND RAG.%NotDel%
		LEFT JOIN %table:SX5% SX5
			ON X5_FILIAL = %xFilial:SX5%
			AND X5_TABELA = 'RI'
			AND X5_CHAVE = RAH_REFER
			AND SX5.%NotDel%	
		
		WHERE  RAH_FILIAL>= %Exp:cFil% AND RAH_FILIAL<= %Exp:MV_PAR02%
			AND RAH_CURSO >= %Exp:MV_PAR03% AND RAH_CURSO <= %Exp:MV_PAR04%
			AND RAH_MATER >= %Exp:MV_PAR05% AND RAH_MATER <= %Exp:MV_PAR06%			
			AND RAH.%NotDel%   	
												
		ORDER BY %Exp:cOrder%                 		
		
	EndSql
	
	//Ŀ
	//Metodo EndQuery ( Classe TRSection )                                    
	//Prepara o relatrio para executar o Embedded SQL.                       
	//ExpA1 : Array com os parametros do tipo Range                           
	//
	oReport:Section(1):EndQuery(/*Array com os parametros do tipo Range*/)	
		
	//Ŀ
	// Inicio da impressao do fluxo do relatrio 
	//
	oReport:SetMeter(RAH->(LastRec()))

	//Ŀ
	// Utiliza a query do Pai  
	//
	oSection2:SetParentQuery()
	oSection2:SetParentFilter( { |cParam| (cAliasQry)->RAH_CURSO == cParam },{ || (cAliasQry)->RAH_CURSO })
	
	//Ŀ
	// Imprime Curso por Pagina  
	//
	If MV_PAR07 == 1   
		oBreak := TRBreak():New(oSection1,oSection1:Cell("RAH_CURSO"),"",.F.) 
		oBreak:SetPageBreak(.T.)	
	EndIf
	
	oSection1:Print()	 //Imprimir
#ENDIF

Return Nil

/*

Ŀ
Funo     TRMR040R3 Autor  Emeron Grassi Rocha    Data  26/07/01 
Ĵ
Descrio  Relatorio de Materiais por Curso.	                      
Ĵ
Sintaxe    TRMR040(void)                                              
Ĵ
 Uso       Generico                                                   
Ĵ
         ATUALIZACOES SOFRIDAS DESDE A CONSTRUAO INICIAL.             
Ĵ
Programador  Data    BOPS   Motivo da Alteracao                     
Ĵ
			   			    										  
ٱ

*/
Function TRMR040R3()

Local cString := "RAH"       	// Alias do arquivo principal (Base)
Local cDesc1  := STR0001		//"Relatorio de Materiais por Curso"
Local cDesc2  := STR0002		//"Ser impresso de acordo com os parametros solicitados pelo"
Local cDesc3  := STR0003		//"usurio."

Private aReturn  := {STR0005,1,STR0006,2,2,1,"",1 }		//"Zebrado"###"Administrao"
Private NomeProg := "TRMR040"
Private aLinha   := {}
Private nLastKey := 0
Private cPerg    := "TRR40A"

//Ŀ
// Variaveis Utilizadas na funcao IMPR                          
//
Private Titulo   := STR0007		//"Relatorio de Materiais por Curso"
Private Colunas  := 132
Private AT_PRG   := "TRR40A"
Private wCabec0  := 1
Private wCabec1  := ""
Private Contfl   := 1
Private Li       := 0
Private nTamanho := "M"

pergunte("TRR40A",.F.)
//Ŀ
// Variaveis utilizadas para parametros                         
// MV_PAR01        //  Filial  De                               
// MV_PAR02        //  Filial  Ate                              
// MV_PAR03        //  Curso De                                 
// MV_PAR04        //  Curso Ate                                
// MV_PAR05        //  Material De                              
// MV_PAR06        //  Material Ate                             
// MV_PAR07        //  Impr. um curso por folha S/N             
//

wnrel:="TRR40A"		//Nome Default do relatorio em Disco
wnrel:=SetPrint(cString,wnrel,cPerg,@Titulo,cDesc1,cDesc2,cDesc3,.F.,,.F.,ntamanho)

If nLastKey = 27
	Return
EndIf

SetDefault(aReturn,cString)

If nLastKey = 27
	Return
EndIf

RptStatus({|lEnd| Tr040Imp(@lEnd,wnRel,cString)},Titulo)

Return

/*


Ŀ
Funo     Tr040Imp  Autor  Emerson Grassi Rocha   Data  26/07/01 
Ĵ
Descrio  Funcao que imprime os cursos                               
Ĵ
Sintaxe    Tr040Imp(lEnd,wnRel,cString)                               
Ĵ
Parametros lEnd        - Ao do Codelock                             
           wnRel       - Ttulo do relatrio                          
           cString     - Mensagem			                          
Ĵ
 Uso       TRMR040                                                    
ٱ

*/
Static Function Tr040Imp(lEnd,WnRel,cString )

Local cDet
Local lImp	    := .F.
Local cDescCur, cDescMat, cDescRef, cCurso, cObs
Local cAcessaRAH:= &("{ || " + ChkRH(FunName(),"RAH","2") + "}")

dbSelectArea("RAH")
dbSetOrder(1)

wcabec1 := STR0008	//"COD.   MATERIAL                       REFERENCIA                        OBSERVACOES"

cFil := xFilial("RAH", MV_PAR01)
dbSeek(cFil + MV_PAR03 , .T.)

//-------------------------------------------------------------------------------------------------
// Foi feito este tratamento pois a tabela RAH  representada no padrao como compartilhada,
// sendo necessario fazer o tratamento se  exclusiva ou compartilhada, antes de aplicar o While
//-------------------------------------------------------------------------------------------------
If Empty(cFil)
	cInicio  := "RAH->RAH_CURSO"
	cFim     := MV_PAR04
Else
	cInicio  := "RAH->RAH_FILIAL + RAH->RAH_CURSO"
	cFim     := MV_PAR02 + MV_PAR04
Endif

If RAH->RAH_FILIAL > MV_PAR02
	Help("",1,"TRR040FILI")				// Nao existe curso neste intervalo de filial
	Return Nil
EndIf

SetRegua(RAH->(RecCount()))

While !Eof() .And. &cInicio <= cFim

	IncRegua()
	
	If lEnd
		Exit
	EndIf
               
	If !Eval(cAcessaRAH)
		dbSkip()  
		Loop
	EndIf
	
	If	RAH->RAH_MATER < MV_PAR05 .Or. RAH->RAH_MATER > MV_PAR06	// Material DE/ATE
		dbSkip()
		Loop
	EndIf	
	lImp 	:= .T.
	cCurso	:= RAH->RAH_CURSO
	cDescCur:= FDesc("RA1",cCurso,"RA1->RA1_DESC",30)
	cDet 	:= STR0009 + cCurso + " - " + cDescCur //"CURSO: "
	
	IMPR(cDet,"C")
	IMPR("","C")
				
	While !Eof() .And. RAH->RAH_CURSO == cCurso

		cDescMat	:= FDesc("RAG",RAH->RAH_MATER,"RAG->RAG_DESC",30)
		cObs		:= FDesc("RAG",RAH->RAH_MATER,"RAG->RAG_OBS",60)
		cDescRef	:= FDesc("SX5","RI"+RAH->RAH_REFER,"SX5->X5_DESCRI",30)

	//"COD.   MATERIAL                       REFERENCIA                        OBSERVACOES"
	// 1234 - 123456789012345678901234567890 01-012345678901234567890123456789 012345678901234567890123456789012345678901234567890123456789	
	
		cDet := RAH->RAH_MATER + " - " + cDescMat + SPACE(01)
		cDet += RAH->RAH_REFER + "-" + cDescRef + SPACE(01) 
		cDet += cObs
	
		IMPR(cDet,"C")
	
		dbSelectArea("RAH")
		dbSkip()	
    EndDo
    
	IMPR(__PrtThinLine(),"C")     
    IMPR("","C")
    
	// Imprime um Curso por folha
	If MV_PAR07 == 1 .And. !Eof() 		// 1- Sim
		IMPR("","P")
	EndIf

EndDo

If lImp
	Impr("","F")
EndIf	

dbSelectArea("RAH")
dbSetOrder(1)

If aReturn[5] = 1
	Set Printer To
	Commit
	ourspool(wnrel)
Endif

MS_FLUSH()

Return Nil
